==> CGAL-6.0-doc_html.tar.xz: doc_html/Boolean_set_operations_2/group__PkgBooleanSetOperations2Concepts.js <==
var group__PkgBooleanSetOperations2Concepts =
[
    [ "ArrangementDirectionalXMonotoneTraits_2", "classArrangementDirectionalXMonotoneTraits__2.html", [
      [ "Are_mergeable_2", "classArrangementDirectionalXMonotoneTraits__2.html#a4b43745b58001a1cbc3b219c565222ae", null ],
      [ "Compare_endpoints_xy_2", "classArrangementDirectionalXMonotoneTraits__2.html#aca1c1514700f31371fa310ef30c29fd0", null ],
      [ "Construct_opposite_2", "classArrangementDirectionalXMonotoneTraits__2.html#a5a382c33bbcdcc3bd75d452088410def", null ],
      [ "Intersect_2", "classArrangementDirectionalXMonotoneTraits__2.html#ad96deb2a1f8084be12c5f186a60188a5", null ],
      [ "Merge_2", "classArrangementDirectionalXMonotoneTraits__2.html#a9e4a3ea04f5606871df92e69f14ad1eb", null ],
      [ "Split_2", "classArrangementDirectionalXMonotoneTraits__2.html#a63133d1d46942dc170bcfbf2ef5a142d", null ],
      [ "ArrangementDirectionalXMonotoneTraits_2", "classArrangementDirectionalXMonotoneTraits__2.html#ad9e4f9706ae67685e495c28975a69b3a", null ],
      [ "ArrangementDirectionalXMonotoneTraits_2", "classArrangementDirectionalXMonotoneTraits__2.html#acb81f7a11ac7f702837da765134481fa", null ],
      [ "compare_endpoints_xy_2_object", "classArrangementDirectionalXMonotoneTraits__2.html#a0fa8c0c523758baab522c7e287b33395", null ],
      [ "construct_opposite_2_object", "classArrangementDirectionalXMonotoneTraits__2.html#aee476d507645df0e84c543178fea962a", null ],
      [ "operator=", "classArrangementDirectionalXMonotoneTraits__2.html#a6670226005630c02f20a4cb0938ffeea", null ]
    ] ],
    [ "ArrDirectionalTraits::AreMergeable_2", "classArrDirectionalTraits_1_1AreMergeable__2.html", [
      [ "operator()", "classArrDirectionalTraits_1_1AreMergeable__2.html#a0d5f85e020f4549c51d1bbebccdb3a1b", null ]
    ] ],
    [ "ArrDirectionalTraits::CompareEndpointsXy_2", "classArrDirectionalTraits_1_1CompareEndpointsXy__2.html", [
      [ "operator()", "classArrDirectionalTraits_1_1CompareEndpointsXy__2.html#a87e5b179713620bbda5d13bddcb1a903", null ]
    ] ],
    [ "ArrDirectionalTraits::ConstructOpposite_2", "classArrDirectionalTraits_1_1ConstructOpposite__2.html", [
      [ "operator()", "classArrDirectionalTraits_1_1ConstructOpposite__2.html#a69536a53c75f8ce19255ce85506c849c", null ]
    ] ],
    [ "ArrDirectionalTraits::Intersect_2", "classArrDirectionalTraits_1_1Intersect__2.html", [
      [ "operator()", "classArrDirectionalTraits_1_1Intersect__2.html#a5ca1f63d87def998b7dfa7d2af8a0a8f", null ]
    ] ],
    [ "ArrDirectionalTraits::Merge_2", "classArrDirectionalTraits_1_1Merge__2.html", [
      [ "operator()", "classArrDirectionalTraits_1_1Merge__2.html#ac3b7ea1ad4f2ed3ea8161bc8dba70add", null ]
    ] ],
    [ "ArrDirectionalTraits::Split_2", "classArrDirectionalTraits_1_1Split__2.html", [
      [ "operator()", "classArrDirectionalTraits_1_1Split__2.html#a6a95bcbe3c3c915e125c209a0981b72c", null ]
    ] ],
    [ "GeneralPolygon_2", "classGeneralPolygon__2.html", [
      [ "Curve_const_iterator", "classGeneralPolygon__2.html#aab80445fce8c22f894bc0268cef22e75", null ],
      [ "Curve_iterator", "classGeneralPolygon__2.html#a13c9ce25c0983fd9926d6f3a2637945a", null ],
      [ "X_monotone_curve_2", "classGeneralPolygon__2.html#a4b5104ea0a88dbe39a5240f04ee7db8d", null ],
      [ "GeneralPolygon_2", "classGeneralPolygon__2.html#a381863cd4a42c9803306c74a5bf6740d", null ],
      [ "GeneralPolygon_2", "classGeneralPolygon__2.html#adb04ad296966ddcd941720d32428f974", null ],
      [ "GeneralPolygon_2", "classGeneralPolygon__2.html#aeae4de870ed8d4914e38a2863d30c219", null ],
      [ "curves_begin", "classGeneralPolygon__2.html#af914c0684481855c860173c4253aa06d", null ],
      [ "curves_begin", "classGeneralPolygon__2.html#a0bedbf4f5a12f3b672227787b807e141", null ],
      [ "curves_end", "classGeneralPolygon__2.html#aab35e10aa9d465c39675da92a813be85", null ],
      [ "curves_end", "classGeneralPolygon__2.html#a11747216c14f1252ec62b7d3d6f2190d", null ],
      [ "init", "classGeneralPolygon__2.html#a398ba60df8aedc71c4445f5b467015d4", null ],
      [ "operator=", "classGeneralPolygon__2.html#a44970dbde7e46f759d2ab9545c8c1a26", null ]
    ] ],
    [ "GeneralPolygonSetDcel", "classGeneralPolygonSetDcel.html", null ],
    [ "GeneralPolygonSetDcelFace", "classGeneralPolygonSetDcelFace.html", [
      [ "contained", "classGeneralPolygonSetDcelFace.html#adaebd8ae8f566af553b1f4eeffc78ca2", null ],
      [ "id", "classGeneralPolygonSetDcelFace.html#a9a6897f38b2ae7b6ccba7f6012195363", null ],
      [ "id_not_set", "classGeneralPolygonSetDcelFace.html#a2ad35c52de20a0b53e1821f9e11971ec", null ],
      [ "reset_id", "classGeneralPolygonSetDcelFace.html#a0ba31caece98312b96a44f07f8eef681", null ],
      [ "set_contained", "classGeneralPolygonSetDcelFace.html#a9d0bb56ecae8bb351162ec035e6862d1", null ],
      [ "set_id", "classGeneralPolygonSetDcelFace.html#ad3083fcae1b26272f75503e25c7a8d91", null ],
      [ "visited", "classGeneralPolygonSetDcelFace.html#ac0fbb57b7b5349cd8280f2e9c3afec6a", null ]
    ] ],
    [ "GeneralPolygonSetDcelHalfedge", "classGeneralPolygonSetDcelHalfedge.html", [
      [ "flag", "classGeneralPolygonSetDcelHalfedge.html#ab933b0c5beeeb25ff869ce58b35486c0", null ],
      [ "set_flag", "classGeneralPolygonSetDcelHalfedge.html#ae4e52e7e80200b599d3e27003ae137e0", null ]
    ] ],
    [ "GeneralPolygonSetTraits_2", "classGeneralPolygonSetTraits__2.html", [
      [ "Construct_holes", "classGeneralPolygonSetTraits__2.html#a7ec2fa1bc8b576c1cce3c22eeb069143", null ],
      [ "Construct_outer_boundary", "classGeneralPolygonSetTraits__2.html#a4ad6b2c97c9e50646f38b9612cf76eef", null ],
      [ "Construct_polygon_2", "classGeneralPolygonSetTraits__2.html#a75ad7bf0ef9959942d128d2f4ec33561", null ],
      [ "Construct_polygon_with_holes_2", "classGeneralPolygonSetTraits__2.html#a330299a6d6f8a9b3d35602888513de8f", null ],
      [ "Curve_const_iterator", "classGeneralPolygonSetTraits__2.html#ac8fd04db1596fe9d882a96caf97bc0df", null ],
      [ "Is_unbounded", "classGeneralPolygonSetTraits__2.html#a9856e77d66d40ae4dce2f7aee3677e3c", null ],
      [ "Polygon_2", "classGeneralPolygonSetTraits__2.html#a6ad5f4a1fb6e2e848b15db43c8eebd6c", null ],
      [ "Polygon_with_holes_2", "classGeneralPolygonSetTraits__2.html#a8cd84c1c2cfd13abeebba291a1a2c516", null ],
      [ "GeneralPolygonSetTraits_2", "classGeneralPolygonSetTraits__2.html#ac33a7826e352bb8dec24815d3b1fc8a0", null ],
      [ "GeneralPolygonSetTraits_2", "classGeneralPolygonSetTraits__2.html#a9fd1cfd82b3162d3ac526dd8f5ef5a78", null ],
      [ "construct_curves_2_object", "classGeneralPolygonSetTraits__2.html#afafa2d4b415735b77cbefabd71af42df", null ],
      [ "construct_holes_object", "classGeneralPolygonSetTraits__2.html#a4b24cd40870dd9607e77ef84ed0e7c43", null ],
      [ "construct_outer_boundary_object", "classGeneralPolygonSetTraits__2.html#a45dd5d5e3db466d29de0f94f5fd87bba", null ],
      [ "construct_polygon_2_object", "classGeneralPolygonSetTraits__2.html#ac8239680e7616cab0477acc7faf5cd6c", null ],
      [ "construct_polygon_with_holes_2_object", "classGeneralPolygonSetTraits__2.html#ad04710dab5c3c434240627fdfb72ab73", null ],
      [ "is_unbounded_object", "classGeneralPolygonSetTraits__2.html#aa83ab7368ffb52cd04056ad9171728e3", null ],
      [ "operator=", "classGeneralPolygonSetTraits__2.html#a044e46618764211b8717fd3918f8e399", null ]
    ] ],
    [ "GpsTraitsGeneralPolygon_2", "classGpsTraitsGeneralPolygon__2.html", null ],
    [ "GpsTraitsGeneralPolygonWithHoles_2", "classGpsTraitsGeneralPolygonWithHoles__2.html", null ],
    [ "GraphicsSceneOptionsPolygonSet2", "classGraphicsSceneOptionsPolygonSet2.html", [
      [ "draw_unbounded", "classGraphicsSceneOptionsPolygonSet2.html#a88b81159e89b0ab27b21e62078b177cf", null ],
      [ "draw_unbounded", "classGraphicsSceneOptionsPolygonSet2.html#ada686573abe87ea23d0f9705c8fd7fb6", null ],
      [ "height", "classGraphicsSceneOptionsPolygonSet2.html#a6c8eee44ee0031321ccba9dbf672e2fb", null ],
      [ "height", "classGraphicsSceneOptionsPolygonSet2.html#a71030449e557fb76a2319098a730d3a1", null ],
      [ "toggle_draw_unbounded", "classGraphicsSceneOptionsPolygonSet2.html#a500973177f0e715044ffbb07797c690c", null ],
      [ "unbounded_face_color", "classGraphicsSceneOptionsPolygonSet2.html#ac1dcdfe6bcfaf8a525cfe7d573d3fecb", null ],
      [ "unbounded_face_color", "classGraphicsSceneOptionsPolygonSet2.html#a5d4769e6916ada199d1d318780811bb3", null ],
      [ "width", "classGraphicsSceneOptionsPolygonSet2.html#adfe20e7a838280e093a9a90ba9839334", null ],
      [ "width", "classGraphicsSceneOptionsPolygonSet2.html#a93cffee9445e83d8d37a83220ac6a095", null ]
    ] ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Boolean_set_operations_2/group__PkgBooleanSetOperations2Concepts.js <==
var group__PkgBooleanSetOperations2Concepts =
[
    [ "AosDirectionalXMonotoneTraits_2", "classAosDirectionalXMonotoneTraits__2.html", [
      [ "Are_mergeable_2", "classAosDirectionalXMonotoneTraits__2.html#acd0aa4159804e0a1ecba0277fe042586", null ],
      [ "Compare_endpoints_xy_2", "classAosDirectionalXMonotoneTraits__2.html#a1cbf9c8f8ca2628ddd884525c543df42", null ],
      [ "Construct_opposite_2", "classAosDirectionalXMonotoneTraits__2.html#a571296b34853c40ece25dda872c80f73", null ],
      [ "Intersect_2", "classAosDirectionalXMonotoneTraits__2.html#ad5f02997cf9353bd52351c90d0fdc148", null ],
      [ "Merge_2", "classAosDirectionalXMonotoneTraits__2.html#a68184b5284e0830198eaf446e9dc2564", null ],
      [ "Split_2", "classAosDirectionalXMonotoneTraits__2.html#a75e3eb427372d013673ee82d90c0db30", null ],
      [ "AosDirectionalXMonotoneTraits_2", "classAosDirectionalXMonotoneTraits__2.html#ab3244ffe08d41c206ca17079708580e0", null ],
      [ "AosDirectionalXMonotoneTraits_2", "classAosDirectionalXMonotoneTraits__2.html#a4c1413e395b8d9a225995a0c474bc2fe", null ],
      [ "compare_endpoints_xy_2_object", "classAosDirectionalXMonotoneTraits__2.html#a79fbc857b2dce2431ab8d984864d25fe", null ],
      [ "construct_opposite_2_object", "classAosDirectionalXMonotoneTraits__2.html#a9359894559ad36d6ebb9caaa2e034e35", null ],
      [ "operator=", "classAosDirectionalXMonotoneTraits__2.html#a63c5db90d17ac0ead49f25f20ff9415b", null ]
    ] ],
    [ "ArrDirectionalTraits::AreMergeable_2", "classArrDirectionalTraits_1_1AreMergeable__2.html", [
      [ "operator()", "classArrDirectionalTraits_1_1AreMergeable__2.html#a0d5f85e020f4549c51d1bbebccdb3a1b", null ]
    ] ],
    [ "ArrDirectionalTraits::CompareEndpointsXy_2", "classArrDirectionalTraits_1_1CompareEndpointsXy__2.html", [
      [ "operator()", "classArrDirectionalTraits_1_1CompareEndpointsXy__2.html#a87e5b179713620bbda5d13bddcb1a903", null ]
    ] ],
    [ "ArrDirectionalTraits::ConstructOpposite_2", "classArrDirectionalTraits_1_1ConstructOpposite__2.html", [
      [ "operator()", "classArrDirectionalTraits_1_1ConstructOpposite__2.html#a69536a53c75f8ce19255ce85506c849c", null ]
    ] ],
    [ "ArrDirectionalTraits::Intersect_2", "classArrDirectionalTraits_1_1Intersect__2.html", [
      [ "operator()", "classArrDirectionalTraits_1_1Intersect__2.html#a5ca1f63d87def998b7dfa7d2af8a0a8f", null ]
    ] ],
    [ "ArrDirectionalTraits::Merge_2", "classArrDirectionalTraits_1_1Merge__2.html", [
      [ "operator()", "classArrDirectionalTraits_1_1Merge__2.html#ac3b7ea1ad4f2ed3ea8161bc8dba70add", null ]
    ] ],
    [ "ArrDirectionalTraits::Split_2", "classArrDirectionalTraits_1_1Split__2.html", [
      [ "operator()", "classArrDirectionalTraits_1_1Split__2.html#a6a95bcbe3c3c915e125c209a0981b72c", null ]
    ] ],
    [ "GeneralPolygon_2", "classGeneralPolygon__2.html", [
      [ "Curve_const_iterator", "classGeneralPolygon__2.html#aab80445fce8c22f894bc0268cef22e75", null ],
      [ "Curve_iterator", "classGeneralPolygon__2.html#a13c9ce25c0983fd9926d6f3a2637945a", null ],
      [ "X_monotone_curve_2", "classGeneralPolygon__2.html#a4b5104ea0a88dbe39a5240f04ee7db8d", null ],
      [ "GeneralPolygon_2", "classGeneralPolygon__2.html#a381863cd4a42c9803306c74a5bf6740d", null ],
      [ "GeneralPolygon_2", "classGeneralPolygon__2.html#adb04ad296966ddcd941720d32428f974", null ],
      [ "GeneralPolygon_2", "classGeneralPolygon__2.html#aeae4de870ed8d4914e38a2863d30c219", null ],
      [ "curves_begin", "classGeneralPolygon__2.html#af914c0684481855c860173c4253aa06d", null ],
      [ "curves_begin", "classGeneralPolygon__2.html#a0bedbf4f5a12f3b672227787b807e141", null ],
      [ "curves_end", "classGeneralPolygon__2.html#aab35e10aa9d465c39675da92a813be85", null ],
      [ "curves_end", "classGeneralPolygon__2.html#a11747216c14f1252ec62b7d3d6f2190d", null ],
      [ "init", "classGeneralPolygon__2.html#a398ba60df8aedc71c4445f5b467015d4", null ],
      [ "operator=", "classGeneralPolygon__2.html#a44970dbde7e46f759d2ab9545c8c1a26", null ]
    ] ],
    [ "GeneralPolygonSetDcel", "classGeneralPolygonSetDcel.html", null ],
    [ "GeneralPolygonSetDcelFace", "classGeneralPolygonSetDcelFace.html", [
      [ "contained", "classGeneralPolygonSetDcelFace.html#adaebd8ae8f566af553b1f4eeffc78ca2", null ],
      [ "id", "classGeneralPolygonSetDcelFace.html#a9a6897f38b2ae7b6ccba7f6012195363", null ],
      [ "id_not_set", "classGeneralPolygonSetDcelFace.html#a2ad35c52de20a0b53e1821f9e11971ec", null ],
      [ "reset_id", "classGeneralPolygonSetDcelFace.html#a0ba31caece98312b96a44f07f8eef681", null ],
      [ "set_contained", "classGeneralPolygonSetDcelFace.html#a9d0bb56ecae8bb351162ec035e6862d1", null ],
      [ "set_id", "classGeneralPolygonSetDcelFace.html#ad3083fcae1b26272f75503e25c7a8d91", null ],
      [ "visited", "classGeneralPolygonSetDcelFace.html#ac0fbb57b7b5349cd8280f2e9c3afec6a", null ]
    ] ],
    [ "GeneralPolygonSetDcelHalfedge", "classGeneralPolygonSetDcelHalfedge.html", [
      [ "flag", "classGeneralPolygonSetDcelHalfedge.html#ab933b0c5beeeb25ff869ce58b35486c0", null ],
      [ "set_flag", "classGeneralPolygonSetDcelHalfedge.html#ae4e52e7e80200b599d3e27003ae137e0", null ]
    ] ],
    [ "GeneralPolygonSetTraits_2", "classGeneralPolygonSetTraits__2.html", [
      [ "Construct_holes", "classGeneralPolygonSetTraits__2.html#a7ec2fa1bc8b576c1cce3c22eeb069143", null ],
      [ "Construct_outer_boundary", "classGeneralPolygonSetTraits__2.html#a4ad6b2c97c9e50646f38b9612cf76eef", null ],
      [ "Construct_polygon_2", "classGeneralPolygonSetTraits__2.html#a75ad7bf0ef9959942d128d2f4ec33561", null ],
      [ "Construct_polygon_with_holes_2", "classGeneralPolygonSetTraits__2.html#a330299a6d6f8a9b3d35602888513de8f", null ],
      [ "Curve_const_iterator", "classGeneralPolygonSetTraits__2.html#ac8fd04db1596fe9d882a96caf97bc0df", null ],
      [ "Is_unbounded", "classGeneralPolygonSetTraits__2.html#a9856e77d66d40ae4dce2f7aee3677e3c", null ],
      [ "Polygon_2", "classGeneralPolygonSetTraits__2.html#a6ad5f4a1fb6e2e848b15db43c8eebd6c", null ],
      [ "Polygon_with_holes_2", "classGeneralPolygonSetTraits__2.html#a8cd84c1c2cfd13abeebba291a1a2c516", null ],
      [ "GeneralPolygonSetTraits_2", "classGeneralPolygonSetTraits__2.html#ac33a7826e352bb8dec24815d3b1fc8a0", null ],
      [ "GeneralPolygonSetTraits_2", "classGeneralPolygonSetTraits__2.html#a9fd1cfd82b3162d3ac526dd8f5ef5a78", null ],
      [ "construct_curves_2_object", "classGeneralPolygonSetTraits__2.html#afafa2d4b415735b77cbefabd71af42df", null ],
      [ "construct_holes_object", "classGeneralPolygonSetTraits__2.html#a4b24cd40870dd9607e77ef84ed0e7c43", null ],
      [ "construct_outer_boundary_object", "classGeneralPolygonSetTraits__2.html#a45dd5d5e3db466d29de0f94f5fd87bba", null ],
      [ "construct_polygon_2_object", "classGeneralPolygonSetTraits__2.html#ac8239680e7616cab0477acc7faf5cd6c", null ],
      [ "construct_polygon_with_holes_2_object", "classGeneralPolygonSetTraits__2.html#ad04710dab5c3c434240627fdfb72ab73", null ],
      [ "is_unbounded_object", "classGeneralPolygonSetTraits__2.html#aa83ab7368ffb52cd04056ad9171728e3", null ],
      [ "operator=", "classGeneralPolygonSetTraits__2.html#a044e46618764211b8717fd3918f8e399", null ]
    ] ],
    [ "GpsTraitsGeneralPolygon_2", "classGpsTraitsGeneralPolygon__2.html", null ],
    [ "GpsTraitsGeneralPolygonWithHoles_2", "classGpsTraitsGeneralPolygonWithHoles__2.html", null ],
    [ "GraphicsSceneOptionsPolygonSet2", "classGraphicsSceneOptionsPolygonSet2.html", [
      [ "draw_unbounded", "classGraphicsSceneOptionsPolygonSet2.html#a88b81159e89b0ab27b21e62078b177cf", null ],
      [ "draw_unbounded", "classGraphicsSceneOptionsPolygonSet2.html#ada686573abe87ea23d0f9705c8fd7fb6", null ],
      [ "height", "classGraphicsSceneOptionsPolygonSet2.html#a6c8eee44ee0031321ccba9dbf672e2fb", null ],
      [ "height", "classGraphicsSceneOptionsPolygonSet2.html#a71030449e557fb76a2319098a730d3a1", null ],
      [ "toggle_draw_unbounded", "classGraphicsSceneOptionsPolygonSet2.html#a500973177f0e715044ffbb07797c690c", null ],
      [ "unbounded_face_color", "classGraphicsSceneOptionsPolygonSet2.html#ac1dcdfe6bcfaf8a525cfe7d573d3fecb", null ],
      [ "unbounded_face_color", "classGraphicsSceneOptionsPolygonSet2.html#a5d4769e6916ada199d1d318780811bb3", null ],
      [ "width", "classGraphicsSceneOptionsPolygonSet2.html#adfe20e7a838280e093a9a90ba9839334", null ],
      [ "width", "classGraphicsSceneOptionsPolygonSet2.html#a93cffee9445e83d8d37a83220ac6a095", null ]
    ] ]
];
